@@ -26,6 +26,7 @@ from hpccm.building_blocks.gnu import gnu
 from hpccm.building_blocks.hdf5 import hdf5
 from hpccm.building_blocks.intel_mpi import intel_mpi
 from hpccm.building_blocks.intel_psxe import intel_psxe
+from hpccm.building_blocks.intel_psxe_runtime import intel_psxe_runtime
 from hpccm.building_blocks.knem import knem
 from hpccm.building_blocks.kokkos import kokkos
 from hpccm.building_blocks.libsim import libsim
@@ -45,6 +46,7 @@ from hpccm.building_blocks.pip import pip
 from hpccm.building_blocks.pnetcdf import pnetcdf
 from hpccm.building_blocks.python import python
 from hpccm.building_blocks.scif import scif
+from hpccm.building_blocks.sensei import sensei
 from hpccm.building_blocks.ucx import ucx
 from hpccm.building_blocks.xpmem import xpmem
 from hpccm.building_blocks.yum import yum
