@@ -22,7 +22,7 @@ from __future__ import unicode_literals
 from __future__ import print_function
 
 import logging # pylint: disable=unused-import
-import os
+import posixpath
 import re
 from six import string_types
 
@@ -157,7 +157,7 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
 
         self.__commands = [] # Filled in by __setup()
         self.__environment_variables = {
-            'PATH': '{}:$PATH'.format(os.path.join(self.prefix, 'bin'))}
+            'PATH': '{}:$PATH'.format(posixpath.join(self.prefix, 'bin'))}
         self.__wd = '/var/tmp' # working directory
 
         # Output toolchain
@@ -184,7 +184,7 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         if self.directory:
             # Use source from local build context
             self += copy(src=self.directory,
-                         dest=os.path.join(self.__wd, self.directory))
+                         dest=posixpath.join(self.__wd, self.directory))
         self += shell(commands=self.__commands)
         if self.__environment_variables:
             self += environment(variables=self.__environment_variables)
@@ -258,25 +258,26 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
                 if self.__toolchain.CUDA_HOME:
                     cuda_home = self.__toolchain.CUDA_HOME
                 self.__commands.append('ln -s {0} {1}'.format(
-                    os.path.join(cuda_home, 'lib64', 'stubs', 'libcuda.so'),
-                    os.path.join(cuda_home, 'lib64', 'stubs', 'libcuda.so.1')))
+                    posixpath.join(cuda_home, 'lib64', 'stubs', 'libcuda.so'),
+                    posixpath.join(cuda_home, 'lib64', 'stubs', 'libcuda.so.1')))
                 if not self.__toolchain.LD_LIBRARY_PATH:
-                    build_environment.append('LD_LIBRARY_PATH="{}:$LD_LIBRARY_PATH"'.format(os.path.join(cuda_home, 'lib64', 'stubs')))
+                    build_environment.append('LD_LIBRARY_PATH="{}:$LD_LIBRARY_PATH"'.format(posixpath.join(cuda_home, 'lib64', 'stubs')))
 
         if self.directory:
             # Use source from local build context
             self.__commands.append(self.configure_step(
-                directory=os.path.join(self.__wd, self.directory),
+                directory=posixpath.join(self.__wd, self.directory),
                 toolchain=self.__toolchain))
         else:
             # Download source from web
             self.__commands.append(self.download_step(url=url,
                                                       directory=self.__wd))
             self.__commands.append(self.untar_step(
-                tarball=os.path.join(self.__wd, tarball), directory=self.__wd))
+                tarball=posixpath.join(self.__wd, tarball),
+                directory=self.__wd))
             self.__commands.append(self.configure_step(
-                directory=os.path.join(self.__wd,
-                                       'openmpi-{}'.format(self.version)),
+                directory=posixpath.join(self.__wd,
+                                         'openmpi-{}'.format(self.version)),
                 environment=build_environment,
                 toolchain=self.__toolchain))
 
@@ -288,7 +289,7 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         self.__commands.append(self.install_step())
 
         # Set library path
-        libpath = os.path.join(self.prefix, 'lib')
+        libpath = posixpath.join(self.prefix, 'lib')
         if self.ldconfig:
             self.__commands.append(self.ldcache_step(directory=libpath))
         else:
@@ -297,13 +298,13 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         if self.directory:
             # Using source from local build context, cleanup directory
             self.__commands.append(self.cleanup_step(
-                items=[os.path.join(self.__wd, self.directory)]))
+                items=[posixpath.join(self.__wd, self.directory)]))
         else:
             # Using downloaded source, cleanup tarball and directory
             self.__commands.append(self.cleanup_step(
-                items=[os.path.join(self.__wd, tarball),
-                       os.path.join(self.__wd,
-                                    'openmpi-{}'.format(self.version))]))
+                items=[posixpath.join(self.__wd, tarball),
+                       posixpath.join(self.__wd,
+                                      'openmpi-{}'.format(self.version))]))
 
     def runtime(self, _from='0'):
         """Generate the set of instructions to install the runtime specific
@@ -324,7 +325,7 @@ class openmpi(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         if self.ldconfig:
             instructions.append(shell(
                 commands=[self.ldcache_step(
-                    directory=os.path.join(self.prefix, 'lib'))]))
+                    directory=posixpath.join(self.prefix, 'lib'))]))
         if self.__environment_variables:
             instructions.append(environment(
                 variables=self.__environment_variables))
